<?php

namespace FiloBlu\Flow\Model\From;

use Exception;
use FiloBlu\Flow\Helper\Data;
use FiloBlu\Flow\Model\Inboundflow;
use FiloBlu\Flow\Model\Processor;
use Magento\Customer\Api\CustomerRepositoryInterface;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\ProductMetadataInterface;
use Magento\Framework\App\ResourceConnection;
use Magento\Framework\Data\Collection\AbstractDb;
use Magento\Framework\Model\Context;
use Magento\Framework\Model\ResourceModel\AbstractResource;
use Magento\Framework\ObjectManagerInterface;
use Magento\Framework\Registry;
use FiloBlu\Flow\Model\From\Entity\Customer as CustomerEntity;
use Magento\Customer\Model\CustomerFactory;

/**
 * Class Customer
 * @package FiloBlu\Flow\Model\From
 */
class Customer extends Eavs {

    protected $customerRepositoryInterface;
    protected $customerFactory;

    public function __construct(
        ScopeConfigInterface $scopeConfig,
        Context $context,
        Registry $registry,
        Data $helperFlow,
        ObjectManagerInterface $objectManager,
        ProductMetadataInterface $productMetadata,
        ResourceConnection $resourceConnection,
        AbstractResource $resource = null,
        AbstractDb $resourceCollection = null,
        CustomerRepositoryInterface $customerRepositoryInterface,
        CustomerFactory $customerFactory,
        array $data = []
    )
    {
        parent::__construct($scopeConfig, $context, $registry, $helperFlow, $objectManager, $productMetadata, $resourceConnection, $resource, $resourceCollection, $data);
        $this->customerRepositoryInterface = $customerRepositoryInterface;
        $this->customerFactory = $customerFactory;
    }

    public function process()
    {
        $customer_email = $this->getData('e');
        $store_code = $this->getData('s');
        $all_store_ids = $this->helper_flow->getAllStoreIds();
        $store_id = $all_store_ids[$store_code];

        $entityType = self::TYPE_MAP['customer'];
        $entityManagerClassName = $this->getEntityManagerClassName($entityType);

        try {
            $this->objectManager->create(
                $entityManagerClassName,
                [
                    'data' => [
                        'entityIdentifier' => $this->getE(),
                        'attributeCode' => $this->getA(),
                        'attributeValue' => stripcslashes($this->getV()),
                        'entityTypeCode' => $entityType,
                        'storeId' => $store_id
                    ]
                ]
            )->process();

        } catch (Exception $e) {
            $this->_logger->info($e->getMessage());
            return $this->error(false, $e->getMessage());
        }

        return $this;
    }

}
